.. _effectSize_bin:

`effectSize_bin`
================

.. automodule:: oasis_stat
   :members: effectSize_bin
   :undoc-members:
   :show-inheritance:
   :noindex:
   
Description
-----------
Computes effect size